summaryrefslogtreecommitdiff
path: root/board/hammer
diff options
context:
space:
mode:
authorNicolas Boichat <drinkcat@google.com>2017-07-22 01:42:59 +0800
committerchrome-bot <chrome-bot@chromium.org>2017-07-25 20:08:34 -0700
commit74d1a312e7aecab4ffc118e2aa33596169a6269d (patch)
treed1aecfe3ff06297a3f70cc83e4d1f6103b59aed6 /board/hammer
parentfdbce2bcf46334ff7aa5de86b73d29ccb0805634 (diff)
downloadchrome-ec-74d1a312e7aecab4ffc118e2aa33596169a6269d.tar.gz
poppy/hammer: Increase sideband wake pulse to 500us
100us is hard to measure reliably on poppy side, let's increase to 500us, and widen the range. BRANCH=none BUG=b:63818321 TEST=Flash staff and soraka EC, check that pulses are detected correctly. Change-Id: I1c29a42c70da0efa0318a619bb83e451b9f168f4 Reviewed-on: https://chromium-review.googlesource.com/581572 Commit-Ready: Nicolas Boichat <drinkcat@chromium.org> Tested-by: Nicolas Boichat <drinkcat@chromium.org> Reviewed-by: Furquan Shaikh <furquan@chromium.org>
Diffstat (limited to 'board/hammer')
-rw-r--r--board/hammer/board.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/board/hammer/board.c b/board/hammer/board.c
index f3d32f468c..2638c0ccec 100644
--- a/board/hammer/board.c
+++ b/board/hammer/board.c
@@ -127,7 +127,7 @@ void board_config_pre_init(void)
void board_usb_wake(void)
{
/*
* Poke detection pin for less than 100us, we disable interrupts
* to make sure that we do not get preempted (setting GPIO high
* for too long would prevent pulse detection on lid EC side from
* working properly, or even kill hammer power if it is held for
@@ -135,7 +135,7 @@ void board_usb_wake(void)
*/
interrupt_disable();
gpio_set_flags(GPIO_BASE_DET, GPIO_OUT_HIGH);
- udelay(100);
+ udelay(500);
gpio_set_flags(GPIO_BASE_DET, GPIO_INPUT);
interrupt_enable();
}
@@ -127,7 +127,7 @@ void board_config_pre_init(void)
{
/*
- * Poke detection pin for less than 100us, we disable interrupts
+ * Poke detection pin for about 500us, we disable interrupts
* to make sure that we do not get preempted (setting GPIO high
* for too long would prevent pulse detection on lid EC side from